@@ -1,11 +1,15 @@
 #ifndef WLR_CONFIG_H
 #define WLR_CONFIG_H
 
-#define WLR_HAS_LIBCAP 1
+#define WLR_HAS_EGLMESAEXT_H 1
+
+/* #undef WLR_HAS_LIBCAP */
 
 #define WLR_HAS_SYSTEMD 1
 #define WLR_HAS_ELOGIND 0
 
+#define WLR_HAS_LIBSEAT 0
+
 #define WLR_HAS_X11_BACKEND 1
 
 #define WLR_HAS_XWAYLAND 1
